==> MI63-7482_171FIS_MIANG.zip: MI63-7482_171FIS_MIANG/description.lua <==
livery = 
	{

		{"HB_F-4E_EXT_ENGINE_L", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_ENGINE_L_RoughMet", true}; --Important - keep for all liveries!

        {"HB_F-4E_EXT_01", 0 ,"HB_F-4E_EXT_01",false};
        {"HB_F-4E_EXT_02", 0 ,"HB_F-4E_EXT_02",false};
        {"HB_F-4E_EXT_03", 0 ,"HB_F-4E_EXT_03",false};
        {"HB_F-4E_EXT_04", 0 ,"HB_F-4E_EXT_04",false};
        {"HB_F-4E_EXT_05", 0 ,"HB_F-4E_EXT_05",false};
        {"HB_F-4E_EXT_06", 0 ,"HB_F-4E_EXT_06",false};
        {"HB_F-4E_EXT_08", 0 ,"HB_F-4E_EXT_08",false};
        {"HB_F-4E_EXT_09", 0 ,"HB_F-4E_EXT_09",false};
		
		{"HB_F-4E_EXT_01", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_01_RoughMet",false};
        {"HB_F-4E_EXT_02", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_02_RoughMet",false};
        {"HB_F-4E_EXT_03", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_03_RoughMet",false};
        {"HB_F-4E_EXT_04", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_04_RoughMet",false};
        {"HB_F-4E_EXT_05", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_05_RoughMet",false};
        {"HB_F-4E_EXT_06", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_06_RoughMet",false};
        {"HB_F-4E_EXT_08", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_08_RoughMet",false};
        {"HB_F-4E_EXT_09", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_09_RoughMet",false};

		{"HB_F-4E_EXT_WeaponPylons",	DIFFUSE			,	"hb_f-4e_ext_weaponpylons", false};
        {"HB_F-4E_EXT_LAU-7", 0 , "HB_F-4E_EXT_LAU-7",false};
	
		{"HB_F-4E_ORD_Pave_Spike", 0 ,"../commons/PS_g/hb_ord_pave_spike", false};
		{"HB_F-4E_ORD_Pave_Spike", ROUGHNESS_METALLIC ,"../commons/PS_g/hb_ord_pave_spike_roughmet", false};

	
		{"HB_ORD_600_Gal_PerformanceTank", 0 ,"../commons/N90/ctank_v1/hb_ord_600_gal_performancetank",false};
		{"HB_ORD_600_Gal_PerformanceTank", ROUGHNESS_METALLIC ,"../commons/N90/ctank_v1/hb_ord_600_gal_performancetank_roughmet",false};
		
		{"HB_F-4E_EXT_WingTank", 0 ,"../commons/N90/wtank_v1/HB_F-4E_EXT_WingTank_R",false};
		{"HB_F-4E_EXT_WingTank", ROUGHNESS_METALLIC ,"../commons/N90/wtank_v1/HB_F-4E_EXT_WingTank_R_RoughMet",false};
		
		{"HB_F-4E_EXT_WingTank_R", 0 ,"../commons/N90/wtank_v2/HB_F-4E_EXT_WingTank_R",false};
		{"HB_F-4E_EXT_WingTank_R", ROUGHNESS_METALLIC ,"../commons/N90/wtank_v2/HB_F-4E_EXT_WingTank_R_RoughMet",false};

		
		{"HGU-2_Helmet",	DIFFUSE			,	"hgu-2_helmet", false};
		{"HB_HGU_55_Basic", NORMAL_MAP ,"../commons/HGU55_v4t/hb_hgu_55_basic_nrm",false};
		{"HB_HGU_55_Basic", ROUGHNESS_METALLIC ,"../commons/HGU55_v4t/hb_hgu_55_basic_RoughMet",false};
		
		{"WSO_HGU-2_Helmet",	DIFFUSE			,	"hgu-2_helmet", false};
		{"WSO_HB_HGU_55_Basic", NORMAL_MAP ,"../commons/HGU55_v4t/hb_hgu_55_basic_nrm",false};
		{"WSO_HB_HGU_55_Basic", ROUGHNESS_METALLIC ,"../commons/HGU55_v4t/hb_hgu_55_basic_RoughMet",false};
		
		{"HB_Char_RobinOlds_CWU", 0 ,"../commons/USGFS/hb_char_robinolds_cwu",false};
		{"HB_Char_RobinOlds_overall",	0 ,"../commons/USGFS/hb_char_robinolds_overall", false};
		{"HB_Char_RobinOlds_overall",	NORMAL_MAP ,"../commons/USGFS/hb_char_robinolds_overall_nrm",false};
		{"HB_Char_RobinOlds_overall", ROUGHNESS_METALLIC ,"../commons/USGFS/hb_char_robinolds_overall_roughmet",false};
		
		{"WSO_HB_Char_RobinOlds_CWU", 0 ,"../commons/USGFS/hb_char_robinolds_cwu",false};
		{"WSO_HB_Char_RobinOlds_overall", 0 ,"../commons/USGFS/hb_char_robinolds_overall",false};
		{"WSO_HB_Char_RobinOlds_overall", NORMAL_MAP ,"../commons/USGFS/hb_char_robinolds_overall_nrm",false};
		{"WSO_HB_Char_RobinOlds_overall", ROUGHNESS_METALLIC ,"../commons/USGFS/hb_char_robinolds_overall_roughmet",false};
		
		{"AM32A60B_01_01", 0 , "../commons/D60G/mi_am32a60b_01_01", false};
		--{"AM32A60B_01_01", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_01_nrm", false};
		{"AM32A60B_01_01", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_01_RoughMet", false};
		{"AM32A60B_01_02", 0 , "../commons/D60G/mi_am32a60b_01_02", false};
		--{"AM32A60B_01_02", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_02_nrm", false};
		{"AM32A60B_01_02", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_02_RoughMet", false};
		{"AM32A60B_01_03", 0 , "../commons/D60G/mi_am32a60b_01_03", false};
		--{"AM32A60B_01_03", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_03_nrm", false};
		{"AM32A60B_01_03", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_03_RoughMet", false};
		{"AM32A60B_01_04", 0 , "../commons/D60G/mi_am32a60b_01_04", false};
		--{"AM32A60B_01_04", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_04_nrm", false};
		{"AM32A60B_01_04", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_04_RoughMet", false};
		{"AM32A60B_01_05", 0 , "../commons/D60G/mi_am32a60b_01_05", false};
		--{"AM32A60B_01_05", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_05_nrm", false};
		{"AM32A60B_01_05", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_05_RoughMet", false};
		{"AM32A60B_01_06", 0 , "../commons/D60G/mi_am32a60b_01_06", false};
		--{"AM32A60B_01_06", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_06_nrm", false};
		{"AM32A60B_01_06", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_06_RoughMet", false};
		
		{"HB_F4E_Boarding_Ladder", 0 , "../commons/bl/h2/HB_F4E_Boarding_Ladder", false};
		{"HB_F4E_Boarding_Ladder", NORMAL_MAP , "../commons/bl/h2/HB_F4E_Boarding_Ladder_nrm", false};
		{"HB_F4E_Boarding_Ladder", ROUGHNESS_METALLIC , "../commons/bl/h2/HB_F4E_Boarding_Ladder_RoughMet", false};
		
		{"HB_F-4E_EXT_FrontGearDoor", 0, "hb_f_4e_ext_frontgeardoor", true};
		{"HB_F-4E_EXT_FrontGearDoor", NORMAL_MAP, "hb_f_4e_ext_frontgeardoor_nrm", true};
		
		
    }
	
	
custom_args = 
	{
		[512] = 0.0, -- 0 is no mirrors, 0 - 0.4 is both mirrors (mickey mouse) and  0.5+ is top mirror only.
		[2008] = 0.00, --WSO Helmet, 0.00 is HGU-2
		[2006] = 0.00, --Pilot Helmet, 0.00 is HGU-2
	}
    
    name = "F-4E - USAF - MI63-7482 - Patience My Ass - 171st FIS Six Pack, MI ANG"

==> MI63-7583_171FIS_MIANG.zip: MI63-7583_171FIS_MIANG/description.lua <==
livery = 
	{

		{"HB_F-4E_EXT_ENGINE_L", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_ENGINE_L_RoughMet", true}; --Important - keep for all liveries!

        {"HB_F-4E_EXT_01", 0 ,"HB_F-4E_EXT_01",false};
        {"HB_F-4E_EXT_02", 0 ,"HB_F-4E_EXT_02",false};
        {"HB_F-4E_EXT_03", 0 ,"HB_F-4E_EXT_03",false};
        {"HB_F-4E_EXT_04", 0 ,"HB_F-4E_EXT_04",false};
        {"HB_F-4E_EXT_05", 0 ,"HB_F-4E_EXT_05",false};
        {"HB_F-4E_EXT_06", 0 ,"HB_F-4E_EXT_06",false};
        {"HB_F-4E_EXT_08", 0 ,"HB_F-4E_EXT_08",false};
        {"HB_F-4E_EXT_09", 0 ,"HB_F-4E_EXT_09",false};
		
		{"HB_F-4E_EXT_01", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_01_RoughMet",false};
        {"HB_F-4E_EXT_02", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_02_RoughMet",false};
        {"HB_F-4E_EXT_03", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_03_RoughMet",false};
        {"HB_F-4E_EXT_04", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_04_RoughMet",false};
        {"HB_F-4E_EXT_05", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_05_RoughMet",false};
        {"HB_F-4E_EXT_06", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_06_RoughMet",false};
        {"HB_F-4E_EXT_08", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_08_RoughMet",false};
        {"HB_F-4E_EXT_09", ROUGHNESS_METALLIC ,"HB_F-4E_EXT_09_RoughMet",false};

		{"HB_F-4E_EXT_WeaponPylons",	DIFFUSE			,	"hb_f-4e_ext_weaponpylons", false};
        {"HB_F-4E_EXT_LAU-7", 0 , "HB_F-4E_EXT_LAU-7",false};
	
		{"HB_F-4E_ORD_Pave_Spike", 0 ,"../commons/PS_g/hb_ord_pave_spike", false};
		{"HB_F-4E_ORD_Pave_Spike", ROUGHNESS_METALLIC ,"../commons/PS_g/hb_ord_pave_spike_roughmet", false};

	
		{"HB_ORD_600_Gal_PerformanceTank", 0 ,"../commons/N90/ctank_v1/hb_ord_600_gal_performancetank",false};
		{"HB_ORD_600_Gal_PerformanceTank", ROUGHNESS_METALLIC ,"../commons/N90/ctank_v1/hb_ord_600_gal_performancetank_roughmet",false};
		
		{"HB_F-4E_EXT_WingTank", 0 ,"../commons/N90/wtank_v1/HB_F-4E_EXT_WingTank_R",false};
		{"HB_F-4E_EXT_WingTank", ROUGHNESS_METALLIC ,"../commons/N90/wtank_v1/HB_F-4E_EXT_WingTank_R_RoughMet",false};
		
		{"HB_F-4E_EXT_WingTank_R", 0 ,"../commons/N90/wtank_v2/HB_F-4E_EXT_WingTank_R",false};
		{"HB_F-4E_EXT_WingTank_R", ROUGHNESS_METALLIC ,"../commons/N90/wtank_v2/HB_F-4E_EXT_WingTank_R_RoughMet",false};

		
		{"HGU-2_Helmet",	DIFFUSE			,	"hgu-2_helmet", false};
		{"HB_HGU_55_Basic", NORMAL_MAP ,"../commons/HGU55_v4t/hb_hgu_55_basic_nrm",false};
		{"HB_HGU_55_Basic", ROUGHNESS_METALLIC ,"../commons/HGU55_v4t/hb_hgu_55_basic_RoughMet",false};
		
		{"WSO_HGU-2_Helmet",	DIFFUSE			,	"hgu-2_helmet", false};
		{"WSO_HB_HGU_55_Basic", NORMAL_MAP ,"../commons/HGU55_v4t/hb_hgu_55_basic_nrm",false};
		{"WSO_HB_HGU_55_Basic", ROUGHNESS_METALLIC ,"../commons/HGU55_v4t/hb_hgu_55_basic_RoughMet",false};
		
		{"HB_Char_RobinOlds_CWU", 0 ,"../commons/USGFS/hb_char_robinolds_cwu",false};
		{"HB_Char_RobinOlds_overall",	0 ,"../commons/USGFS/hb_char_robinolds_overall", false};
		{"HB_Char_RobinOlds_overall",	NORMAL_MAP ,"../commons/USGFS/hb_char_robinolds_overall_nrm",false};
		{"HB_Char_RobinOlds_overall", ROUGHNESS_METALLIC ,"../commons/USGFS/hb_char_robinolds_overall_roughmet",false};
		
		{"WSO_HB_Char_RobinOlds_CWU", 0 ,"../commons/USGFS/hb_char_robinolds_cwu",false};
		{"WSO_HB_Char_RobinOlds_overall", 0 ,"../commons/USGFS/hb_char_robinolds_overall",false};
		{"WSO_HB_Char_RobinOlds_overall", NORMAL_MAP ,"../commons/USGFS/hb_char_robinolds_overall_nrm",false};
		{"WSO_HB_Char_RobinOlds_overall", ROUGHNESS_METALLIC ,"../commons/USGFS/hb_char_robinolds_overall_roughmet",false};
		
		{"AM32A60B_01_01", 0 , "../commons/D60G/mi_am32a60b_01_01", false};
		--{"AM32A60B_01_01", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_01_nrm", false};
		{"AM32A60B_01_01", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_01_RoughMet", false};
		{"AM32A60B_01_02", 0 , "../commons/D60G/mi_am32a60b_01_02", false};
		--{"AM32A60B_01_02", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_02_nrm", false};
		{"AM32A60B_01_02", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_02_RoughMet", false};
		{"AM32A60B_01_03", 0 , "../commons/D60G/mi_am32a60b_01_03", false};
		--{"AM32A60B_01_03", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_03_nrm", false};
		{"AM32A60B_01_03", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_03_RoughMet", false};
		{"AM32A60B_01_04", 0 , "../commons/D60G/mi_am32a60b_01_04", false};
		--{"AM32A60B_01_04", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_04_nrm", false};
		{"AM32A60B_01_04", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_04_RoughMet", false};
		{"AM32A60B_01_05", 0 , "../commons/D60G/mi_am32a60b_01_05", false};
		--{"AM32A60B_01_05", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_05_nrm", false};
		{"AM32A60B_01_05", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_05_RoughMet", false};
		{"AM32A60B_01_06", 0 , "../commons/D60G/mi_am32a60b_01_06", false};
		--{"AM32A60B_01_06", NORMAL_MAP , "../commons/D60G/mi_am32a60b_01_06_nrm", false};
		{"AM32A60B_01_06", ROUGHNESS_METALLIC , "../commons/D60G/mi_am32a60b_01_06_RoughMet", false};
		
		{"HB_F4E_Boarding_Ladder", 0 , "../commons/bl/h2/HB_F4E_Boarding_Ladder", false};
		{"HB_F4E_Boarding_Ladder", NORMAL_MAP , "../commons/bl/h2/HB_F4E_Boarding_Ladder_nrm", false};
		{"HB_F4E_Boarding_Ladder", ROUGHNESS_METALLIC , "../commons/bl/h2/HB_F4E_Boarding_Ladder_RoughMet", false};
		
		{"HB_F-4E_EXT_FrontGearDoor", 0, "hb_f_4e_ext_frontgeardoor", true};
		{"HB_F-4E_EXT_FrontGearDoor", NORMAL_MAP, "hb_f_4e_ext_frontgeardoor_nrm", true};
		
		
    }
	
	
custom_args = 
	{
		[512] = 0.00, -- 0 is no mirrors, 0 - 0.4 is both mirrors (mickey mouse) and  0.5+ is top mirror only.
		[2008] = 0.00, --WSO Helmet, 0.00 is HGU-2
		[2006] = 0.00, --Pilot Helmet, 0.00 is HGU-2
	}
    
    name = "F-4E - USAF - MI63-7583 - Never Trust A Smiling Cat - 171 FIS/191 FIG, Selfridge AFB MI ANG"
